@@ -1,4 +1,9 @@
 package PPIx::EditorTools::FindVariableDeclaration;
+BEGIN {
+  $PPIx::EditorTools::FindVariableDeclaration::VERSION = '0.11';
+}
+
+# ABSTRACT: Finds where a variable was declared using PPI
 
 use 5.008;
 use strict;
@@ -8,7 +13,32 @@ use Carp;
 use base 'PPIx::EditorTools';
 use Class::XSAccessor accessors => { 'location' => 'location' };
 
-our $VERSION = '0.10';
+
+sub find {
+    my ( $self, %args ) = @_;
+    $self->process_doc(%args);
+    my $column = $args{column} or croak "column required";
+    my $line   = $args{line}   or croak "line required";
+    my $location = [ $line, $column ];
+
+    my $ppi = $self->ppi;
+    $ppi->flush_locations;
+
+    my $token = PPIx::EditorTools::find_token_at_location( $ppi, $location );
+    croak "no token" unless $token;
+
+    my $declaration = PPIx::EditorTools::find_variable_declaration($token);
+    croak "no declaration" unless $declaration;
+
+    return PPIx::EditorTools::ReturnObject->new(
+        ppi     => $ppi,
+        element => $declaration,
+    );
+}
+
+1;
+
+
 
 =pod
 
@@ -16,6 +46,10 @@ our $VERSION = '0.10';
 
 PPIx::EditorTools::FindVariableDeclaration - Finds where a variable was declared using PPI
 
+=head1 VERSION
+
+version 0.11
+
 =head1 SYNOPSIS
 
   # finds declaration of variable at cursor
@@ -48,60 +82,49 @@ Accepts either a C<PPI::Document> to process or a string containing
 the code (which will be converted into a C<PPI::Document>) to process.
 Searches for the variable declaration and returns a
 C<PPIx::EditorTools::ReturnObject> with the declaration
-(C<PPI::Statement::Variable>) available via the C<element> accessor. 
+(C<PPI::Statement::Variable>) available via the C<element> accessor.
 
 Croaks with a "no token" exception if no token is found at the location.
 Croaks with a "no declaration" exception if unable to find the declaration.
 
 =back
 
-=cut
-
-sub find {
-    my ( $self, %args ) = @_;
-    $self->process_doc(%args);
-    my $column = $args{column} or croak "column required";
-    my $line   = $args{line}   or croak "line required";
-    my $location = [ $line, $column ];
-
-    my $ppi = $self->ppi;
-    $ppi->flush_locations;
-
-    my $token = PPIx::EditorTools::find_token_at_location( $ppi, $location );
-    croak "no token" unless $token;
-
-    my $declaration = PPIx::EditorTools::find_variable_declaration($token);
-    croak "no declaration" unless $declaration;
-
-    return PPIx::EditorTools::ReturnObject->new(
-        ppi     => $ppi,
-        element => $declaration,
-    );
-}
-
-1;
-
-__END__
-
 =head1 SEE ALSO
 
-This class inherits from C<PPIx::EditorTools>. 
+This class inherits from C<PPIx::EditorTools>.
 Also see L<App::EditorTools>, L<Padre>, and L<PPI>.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Steffen Mueller C<smueller@cpan.org>
-Mark Grimes C<mgrimes@cpan.org>
+
+=item *
+
+Repackaged by Mark Grimes C<mgrimes@cpan.org>
+
+=item *
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 The Padre development team as listed in Padre.pm.
+This software is copyright (c) 2010 by The Padre development team as listed in Padre.pm.
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
