@@ -1,4 +1,9 @@
 package PPIx::EditorTools::IntroduceTemporaryVariable;
+BEGIN {
+  $PPIx::EditorTools::IntroduceTemporaryVariable::VERSION = '0.11';
+}
+
+# ABSTRACT: Introduces a temporary variable using PPI
 
 use 5.008;
 use strict;
@@ -13,65 +18,6 @@ use Class::XSAccessor accessors => {
     'location'       => 'location',
 };
 
-our $VERSION = '0.10';
-
-=pod
-
-=head1 NAME
-
-PPIx::EditorTools::IntroduceTemporaryVariable - Introduces a temporary variable using PPI
-
-=head1 SYNOPSIS
-
-    my $munged = PPIx::EditorTools::IntroduceTemporaryVariable->new->introduce(
-        code           => "use strict; BEGIN {
-	$^W = 1;
-}\n\tmy $x = ( 1 + 10 / 12 ) * 2;\n\tmy $y = ( 3 + 10 / 12 ) * 2;\n",
-        start_location => [ 2, 19 ], 
-        end_location   => [ 2, 25 ],
-        varname        => '$foo',
-    );
-    my $modified_code_as_string = $munged->code;
-    my $location_of_new_var_declaration = $munged->element->location;
-
-=head1 DESCRIPTION
-
-Given a region of code within a statement, replaces all occurrences of 
-that code with a temporary variable. Declares and initializes the
-temporary variable right above the statement that included the
-selected expression.
-
-=head1 METHODS
-
-=over 4
-
-=item new()
-
-Constructor. Generally shouldn't be called with any arguments.
-
-=item find( ppi => PPI::Document, start_location => Int, end_location => Int, varname => Str )
-=item find( code => Str, start_location => Int, end_location => Int, varname => Str )
-
-Accepts either a C<PPI::Document> to process or a string containing
-the code (which will be converted into a C<PPI::Document>) to process.
-
-Given the region of code specified by start_location and end_location,
-replaces that code with a temporary variable with the name given
-in varname (defaults to C<tmp>). Declares and initializes
-the temporary variable right above the statement that included the
-selected expression.
-
-Returns a C<PPIx::EditorTools::ReturnObject> with the modified code
-as a string available via the C<code> accessor (or as a C<PPI::Document>
-via the C<ppi> accessor), and the C<PPI::Token> where the new variable
-is declared available via the C<element> accessor.
-
-Croaks with a "no token" exception if no token is found at the location.
-Croaks with a "no statement" exception if unable to find the statement.
-
-=back
-
-=cut
 
 sub introduce {
     my ( $self, %args ) = @_;
@@ -157,27 +103,104 @@ sub introduce {
 
 1;
 
-__END__
+
+
+=pod
+
+=head1 NAME
+
+PPIx::EditorTools::IntroduceTemporaryVariable - Introduces a temporary variable using PPI
+
+=head1 VERSION
+
+version 0.11
+
+=head1 SYNOPSIS
+
+    my $munged = PPIx::EditorTools::IntroduceTemporaryVariable->new->introduce(
+        code           => "use strict; BEGIN {
+	$^W = 1;
+}\n\tmy $x = ( 1 + 10 / 12 ) * 2;\n\tmy $y = ( 3 + 10 / 12 ) * 2;\n",
+        start_location => [ 2, 19 ],
+        end_location   => [ 2, 25 ],
+        varname        => '$foo',
+    );
+    my $modified_code_as_string = $munged->code;
+    my $location_of_new_var_declaration = $munged->element->location;
+
+=head1 DESCRIPTION
+
+Given a region of code within a statement, replaces all occurrences of
+that code with a temporary variable. Declares and initializes the
+temporary variable right above the statement that included the
+selected expression.
+
+=head1 METHODS
+
+=over 4
+
+=item new()
+
+Constructor. Generally shouldn't be called with any arguments.
+
+=item find( ppi => PPI::Document, start_location => Int, end_location => Int, varname => Str )
+=item find( code => Str, start_location => Int, end_location => Int, varname => Str )
+
+Accepts either a C<PPI::Document> to process or a string containing
+the code (which will be converted into a C<PPI::Document>) to process.
+
+Given the region of code specified by start_location and end_location,
+replaces that code with a temporary variable with the name given
+in varname (defaults to C<tmp>). Declares and initializes
+the temporary variable right above the statement that included the
+selected expression.
+
+Returns a C<PPIx::EditorTools::ReturnObject> with the modified code
+as a string available via the C<code> accessor (or as a C<PPI::Document>
+via the C<ppi> accessor), and the C<PPI::Token> where the new variable
+is declared available via the C<element> accessor.
+
+Croaks with a "no token" exception if no token is found at the location.
+Croaks with a "no statement" exception if unable to find the statement.
+
+=back
 
 =head1 SEE ALSO
 
-This class inherits from C<PPIx::EditorTools>. 
+This class inherits from C<PPIx::EditorTools>.
 Also see L<App::EditorTools>, L<Padre>, and L<PPI>.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Steffen Mueller C<smueller@cpan.org>
-Mark Grimes C<mgrimes@cpan.org>
+
+=item *
+
+Repackaged by Mark Grimes C<mgrimes@cpan.org>
+
+=item *
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 The Padre development team as listed in Padre.pm.
+This software is copyright (c) 2010 by The Padre development team as listed in Padre.pm.
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
